@@ -66,7 +66,7 @@ class JobStatistic(UserDict):
                fpTime = open(timePath,'r')
                try:
                   self[statistic] = float(fpTime.readline())
-                  self.logger.log(logging.DEBUG,getLogMessage("recordTime: %s %s %f" % (timePath,statistic,self[statistic])))
+#                 self.logger.log(logging.DEBUG,getLogMessage("recordTime: %s %s %f" % (timePath,statistic,self[statistic])))
                except (IOError,OSError):
                   self.logger.log(logging.ERROR,getLogMessage("%s could not be read" % (timePath)))
                finally:
@@ -78,7 +78,7 @@ class JobStatistic(UserDict):
 
    def recordTimer(self,
                    timerPath):
-      self.logger.log(logging.DEBUG,getLogMessage("recordTimer: %s" % (timerPath)))
+#     self.logger.log(logging.DEBUG,getLogMessage("recordTimer: %s" % (timerPath)))
       if os.path.exists(timerPath):
          venue       = None
          jobId       = None
@@ -129,11 +129,21 @@ class JobStatistic(UserDict):
                      else:
                         if len(parts) > 2:
                            if parts[-2] == "status":
-                              exitStatus = int(float(parts[-1]))
+                              try:
+                                 exitStatus = int(float(parts[-1]))
+                              except ValueError:
+                                 message = "recordTimer:exitStatus = %s" % (parts[-1])
+                                 self.logger.log(logging.DEBUG,getLogMessage(message))
+                                 exitStatus = 0
                            if parts[-2] == "signal":
 # Killed by signal 2.
                               exitStatus = 1
-                              exitSignal = int(float(parts[-1]))
+                              try:
+                                 exitSignal = int(float(parts[-1]))
+                              except ValueError:
+                                 message = "recordTimer:exitSignal = %s" % (parts[-1])
+                                 self.logger.log(logging.DEBUG,getLogMessage(message))
+                                 exitStatus = 0
                         if re.search("Killed",line):
                            exitStatus = 1
                            exitSignal = 15
