@@ -368,16 +368,19 @@ class MessageCore:
                       channel,
                       messageLength,
                       bufferSize=128):
-      if self.isBlockingChannel(channel):
-#        self.logger.log(logging.DEBUG,getLogMessage("MessageCore:receiveMessage(blocked,%d): %d" % \
-#                                                                 (bufferSize,channel.fileno())))
-         message = self.__receiveBlockingMessage(channel,messageLength,bufferSize)
-#        self.logger.log(logging.DEBUG,getLogMessage("MessageCore:receiveMessage(blocked): %d %s" % \
-#                                                                    (channel.fileno(),message)))
+      if channel:
+         if self.isBlockingChannel(channel):
+#           self.logger.log(logging.DEBUG,getLogMessage("MessageCore:receiveMessage(blocked,%d): %d" % \
+#                                                                    (bufferSize,channel.fileno())))
+            message = self.__receiveBlockingMessage(channel,messageLength,bufferSize)
+#           self.logger.log(logging.DEBUG,getLogMessage("MessageCore:receiveMessage(blocked): %d %s" % \
+#                                                                       (channel.fileno(),message)))
+         else:
+            message = self.__receiveNonBlockingMessage(channel,bufferSize)
+#           self.logger.log(logging.DEBUG,getLogMessage("MessageCore:receiveMessage(nonblocked): %d %s" % \
+#                                                                       (channel.fileno(),message)))
       else:
-         message = self.__receiveNonBlockingMessage(channel,bufferSize)
-#        self.logger.log(logging.DEBUG,getLogMessage("MessageCore:receiveMessage(nonblocked): %d %s" % \
-#                                                                    (channel.fileno(),message)))
+         message = None
 
       return(message)
 
@@ -431,9 +434,16 @@ class MessageCore:
                   self.logger.log(logging.ERROR,getLogMessage("socket connection broken in sendBlockingMessage()"))
                   transmittedLength = -1
                   break
-      except SSL.Error, err:
-         (lib,function,reason) = err.args[0][0]
-         self.logger.log(logging.ERROR,getLogMessage("sendBlockingMessage: SSL error, %s" % (reason)))
+      except SSL.Error,err:
+         if isinstance(err.args,tuple):
+            if not err[0] in [EPIPE]:
+               self.logger.log(logging.ERROR,getLogMessage("Unexpected error in sendBlockingMessage(%s)" % (message[0:20])))
+               self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
+            else:
+               self.logger.log(logging.ERROR,getLogMessage("sendBlockingMessage: Broken pipe"))
+         else:
+            self.logger.log(logging.ERROR,getLogMessage("Unexpected error in sendBlockingMessage(%s)" % (message[0:20])))
+            self.logger.log(logging.ERROR,getLogMessage(traceback.format_exc()))
          transmittedLength = -1
       except Exception,err:
          if isinstance(err.args,tuple):
